@@ -1,16 +1,14 @@
-from aiotfm import utils, errors, enums
+from aiotfm import enums, errors, utils
+from aiotfm.__version__ import __author__, __credits__, __description__, __license__, __title__, __url__, __version__
 from aiotfm.client import Client
 from aiotfm.connection import Connection
 from aiotfm.enums import GameMode
 from aiotfm.packet import Packet
 from aiotfm.player import Player, Profile, Stats
-from aiotfm.tribe import Tribe, Member, Rank
-
-from aiotfm.__version__ import __author__, __title__, __description__
-from aiotfm.__version__ import __url__, __version__, __credits__, __license__
+from aiotfm.tribe import Member, Rank, Tribe
 
 __all__ = [
 	'__author__', '__credits__', '__description__', '__license__', '__title__', '__url__',
 	'__version__', 'enums', 'errors', 'utils', 'Client', 'Connection', 'Member', 'Packet',
 	'Player', 'Profile', 'Rank', 'Stats', 'Tribe', 'GameMode'
-]
\ No newline at end of file
+]
