@@ -1,5 +1,9 @@
+from typing import List
+
+import aiotfm
 from aiotfm.enums import ChatCommunity
 from aiotfm.packet import Packet
+from aiotfm.player import Player
 
 
 class Message:
@@ -10,16 +14,13 @@ class Message:
 	----------
 	author: :class:`aiotfm.Player`
 		The message's author.
-	community: :class:`aiotfm.enums.ChatCommunity`
-		The author's community. Note: the community isn't the author's language!
 	content: `str`
 		The actual content of the message.
 	"""
-	def __init__(self, author, content, community, client):
-		self.author = author
-		self.community = ChatCommunity(community)
-		self.content = content
-		self._client = client
+	def __init__(self, author: Player, content: str, client: 'aiotfm.Client'):
+		self.author: Player = author
+		self.content: str = content
+		self._client: aiotfm.Client = client
 
 	def __str__(self):
 		return '[{0.author}] {0.content}'.format(self)
@@ -48,11 +49,11 @@ class Whisper(Message):
 	sent: `bool`
 		True if the author is the client.
 	"""
-	def __init__(self, author, community, receiver, content, client):
-		super().__init__(author, content, community, client)
-		self.receiver = receiver
-
-		self.sent = self.author == client.username
+	def __init__(self, author: Player, community: ChatCommunity, receiver: Player, content: str, client: 'aiotfm.Client'):
+		super().__init__(author, content, client)
+		self.receiver: Player = receiver
+		self.community: ChatCommunity = ChatCommunity(community)
+		self.sent: bool = self.author == client.username
 
 	def __str__(self):
 		direction = '<' if self.sent else '>'
@@ -60,7 +61,7 @@ class Whisper(Message):
 		commu = '' if self.sent else '[{}] '.format(self.community.name)
 		return f'{direction} {commu}[{author}] {self.content}'
 
-	async def reply(self, msg):
+	async def reply(self, msg: str):
 		"""|coro|
 		Reply to the author of the message. Shortcut to :meth:`aiotfm.Client.whisper`.
 		:param msg: :class:`str` the message."""
@@ -75,9 +76,9 @@ class Channel:
 	name: `str`
 		The actual channel's name.
 	"""
-	def __init__(self, name, client):
-		self.name = name
-		self._client = client
+	def __init__(self, name: str, client: 'aiotfm.Client'):
+		self.name: str = name
+		self._client: aiotfm.Client = client
 
 	def __repr__(self):
 		return '<Channel name={.name}>'.format(self)
@@ -87,7 +88,7 @@ class Channel:
 			return self.name == other
 		return self.name == other.name
 
-	async def send(self, message):
+	async def send(self, message: str):
 		"""|coro|
 		Sends a message to the channel.
 
@@ -99,7 +100,7 @@ class Channel:
 		Leaves the channel."""
 		await self._client.leaveChannel(self)
 
-	async def who(self):
+	async def who(self) -> List[Player]:
 		"""|coro|
 		Sends the command /who to the channel and returns the list of players.
 
@@ -126,11 +127,12 @@ class ChannelMessage(Message):
 		The author's community. Note: the community isn't the author's language!
 	content: `str`
 		The actual content of the message."""
-	def __init__(self, author, community, content, channel):
-		super().__init__(author, content, community, channel._client)
-		self.channel = channel
+	def __init__(self, author: Player, community: ChatCommunity, content: str, channel: Channel):
+		super().__init__(author, content, channel._client)
+		self.channel: Channel = channel
+		self.community: ChatCommunity = ChatCommunity(community)
 
-	async def reply(self, message):
+	async def reply(self, message: str):
 		"""|coro|
 		Sends a message to the channel.
 
@@ -138,4 +140,4 @@ class ChannelMessage(Message):
 		await self.channel.send(message)
 
 	def __str__(self):
-		return '{0.channel.name} [{0.community.value}] [{0.author}] {0.content}'.format(self)
\ No newline at end of file
+		return '(#{0.channel.name}) [{0.community.value}] [{0.author}] {0.content}'.format(self)
